@@ -1,12 +1,13 @@
 from themispy.scrapy.items import FileDownloader
-from themispy.scrapy.pipelines import BlobUploadPipeline, FileDownloaderPipeline
+from themispy.scrapy.pipelines import (AzureBlobUploadPipeline,
+                                       AzureFileDownloaderPipeline)
 from themispy.scrapy.readers import read_jsonl
 from themispy.scrapy.spiders import run_spider
 
 __all__ = [
     "FileDownloader",
-    "BlobUploadPipeline",
-    "FileDownloaderPipeline",
+    "AzureBlobUploadPipeline",
+    "AzureFileDownloaderPipeline",
     "read_jsonl",
     "run_spider"
 ]
